from yoovo.app import app, YoovoApp
from yoovo.screen import Screen, _yoovo_num
from yoovo.widgets.Button import Button
from yoovo.widgets.Label import Label
from yoovo.widgets.TextBox import TextBox
from yoovo.widgets.Toggle import Toggle
from yoovo.widgets.CheckBox import CheckBox
from yoovo.widgets.ProgressBar import ProgressBar
from yoovo.widgets.RadioButton import RadioButton
from yoovo.widgets.NumericInput import NumericInput
from yoovo.widgets.ListBox import ListBox
from yoovo.widgets.DateTimePicker import DateTimePicker

__all__ = [
    'app', 'YoovoApp', 'Screen', '_yoovo_num',
    'Button', 'Label', 'TextBox', 'Toggle', 'CheckBox',
    'ProgressBar', 'Slider', 'Image', 'RadioButton',
    'NumericInput', 'ListBox', 'Chart', 'Panel', 'Video',
    'ColorPicker', 'DateTimePicker', 'Loader', 'Layout',
]



from setuptools import setup, find_packages

setup(
    name='yoovo',
    version='64.0.33',
    packages=find_packages(),
    package_data={
        'yoovo': [
            '*.so',
            'shared/*.so',
            'hardware/*.so',
            'hardware/rpi/*.so',
            'hardware/rpi/i2c_sensor_lib/*.so',
            'widgets/*.so',
        ],
    },
    author="David Sfeir",
    author_email="david.sfeir@yoovo.io",
    description="Added analog arguments",
    keywords=['pip', 'yoovo'],
)